@@ -15,6 +15,8 @@
 import logging
 
 from appium.webdriver.webdriver import WebDriver as AppiumWebDriver
+
+from src.testproject.classes import StepSettings
 from src.testproject.enums import EnvironmentVariable
 from src.testproject.helpers import ReportHelper, LoggingHelper, ConfigHelper, AddonHelper
 from src.testproject.rest import ReportSettings
@@ -23,6 +25,7 @@ from src.testproject.sdk.internal.agent import AgentClient
 from src.testproject.sdk.internal.helpers import CustomAppiumCommandExecutor
 from src.testproject.sdk.internal.reporter import Reporter
 from src.testproject.sdk.internal.session import AgentSession
+import os
 
 
 class Remote(AppiumWebDriver):
@@ -31,8 +34,8 @@ class Remote(AppiumWebDriver):
     Args:
         desired_capabilities (dict): Automation session desired capabilities and options
         token (str): Developer token to be used to communicate with the Agent
-        projectname (str): Project name to report
-        jobname (str): Job name to report
+        project_name (str): Project name to report
+        job_name (str): Job name to report
         disable_reports (bool): set to True to disable all reporting (no report will be created on TestProject)
 
     Attributes:
@@ -50,8 +53,8 @@ class Remote(AppiumWebDriver):
         self,
         desired_capabilities: dict = None,
         token: str = None,
-        projectname: str = None,
-        jobname: str = None,
+        project_name: str = None,
+        job_name: str = None,
         disable_reports: bool = False,
     ):
         if Remote.__instance is not None:
@@ -65,24 +68,24 @@ class Remote(AppiumWebDriver):
 
         if disable_reports:
             # Setting the project and job name to empty strings will cause the Agent to not initialize a report
-            self._projectname = ""
-            self._jobname = ""
+            self._project_name = ""
+            self._job_name = ""
         else:
-            self._projectname = (
-                projectname
-                if projectname is not None
+            self._project_name = (
+                project_name
+                if project_name is not None
                 else ReportHelper.infer_project_name()
             )
-            self._jobname = (
-                jobname if jobname is not None else ReportHelper.infer_job_name()
+            self._job_name = (
+                job_name if job_name is not None else ReportHelper.infer_job_name()
             )
 
-        reportsettings = ReportSettings(self._projectname, self._jobname)
+        report_settings = ReportSettings(self._project_name, self._job_name)
 
         self._agent_client: AgentClient = AgentClient(
             token=self._token,
             capabilities=self._desired_capabilities,
-            reportsettings=reportsettings,
+            report_settings=report_settings,
         )
         self._agent_session: AgentSession = self._agent_client.agent_session
         self.w3c = True if self._agent_session.dialect == "W3C" else False
@@ -101,6 +104,11 @@ class Remote(AppiumWebDriver):
         # this ensures that mobile-specific commands are also available for our command executor
         self._addCommands()
 
+        # Disable automatic command and test reports if Behave reporting is enabled.
+        if os.getenv("TP_DISABLE_AUTO_REPORTING") == "True":
+            self.command_executor.disable_command_reports = True
+            self.command_executor.disable_auto_test_reports = True
+
         Remote.__instance = self
 
     @classmethod
@@ -108,6 +116,14 @@ class Remote(AppiumWebDriver):
         """Returns the singleton instance of the driver object"""
         return Remote.__instance
 
+    @property
+    def step_settings(self):
+        return self.command_executor.settings
+
+    @step_settings.setter
+    def step_settings(self, step_settings: StepSettings):
+        self.command_executor.settings = step_settings
+
     def start_session(self, capabilities, browser_profile=None):
         """Sets capabilities and sessionId obtained from the Agent when creating the original session."""
         self.session_id = self._agent_session.session_id
@@ -123,7 +139,7 @@ class Remote(AppiumWebDriver):
         Returns:
             AddonHelper: object giving access to addon proxy methods
         """
-        return AddonHelper(self._agent_client)
+        return AddonHelper(self._agent_client, self.command_executor)
 
     def quit(self):
         """Quits the driver and stops the session with the Agent, cleaning up after itself."""
