@@ -13,15 +13,17 @@
 # limitations under the License.
 
 import logging
-import requests
-import threading
 import queue
+import threading
 import uuid
-
-from urllib.parse import urljoin
 from enum import Enum, unique
-from requests import HTTPError
+from http import HTTPStatus
+from urllib.parse import urljoin
+
+import requests
 from packaging import version
+from requests import HTTPError
+
 from src.testproject.classes import ActionExecutionResponse
 from src.testproject.classes.resultfield import ResultField
 from src.testproject.enums import ExecutionResultType
@@ -42,7 +44,6 @@ from src.testproject.sdk.exceptions import (
     AgentConnectException,
     InvalidTokenException,
     ObsoleteVersionException,
-    MissingBrowserException,
 )
 from src.testproject.sdk.exceptions.addonnotinstalled import AddonNotInstalledException
 from src.testproject.sdk.internal.session import AgentSession
@@ -55,14 +56,14 @@ class AgentClient:
     Args:
         token (str): The development token used to communicate with the Agent
         capabilities (dict): Additional options to be applied to the driver instance
-        reportsettings (ReportSettings): Settings (project name, job name) to be included in the report
+        report_settings (ReportSettings): Settings (project name, job name) to be included in the report
 
     Attributes:
         _remote_address (str): The Agent endpoint
         _capabilities (dict): Additional options to be applied to the driver instance
         _agent_session (AgentSession): stores properties of the current agent session
         _token (str): The development token used to authenticate with the Agent
-        _reportsettings (ReportSettings): Settings (project name, job name) to be included in the report
+        _report_settings (ReportSettings): Settings (project name, job name) to be included in the report
         _queue (queue.Queue): queue holding reports to be sent to Agent in separate thread
     """
 
@@ -74,12 +75,12 @@ class AgentClient:
     # Class variable containing the current known Agent version
     __agent_version: str = None
 
-    def __init__(self, token: str, capabilities: dict, reportsettings: ReportSettings):
+    def __init__(self, token: str, capabilities: dict, report_settings: ReportSettings):
         self._remote_address = ConfigHelper.get_agent_service_address()
         self._capabilities = capabilities
         self._agent_session = None
         self._token = token
-        self._reportsettings = reportsettings
+        self._report_settings = report_settings
         self._queue = queue.Queue()
 
         self._running = True
@@ -144,7 +145,7 @@ class AgentClient:
         Returns:
             SessionResponse: object containing the response to the session request
         """
-        session_request = SessionRequest(self._capabilities, self._reportsettings)
+        session_request = SessionRequest(self._capabilities, self._report_settings)
 
         logging.info(f"Session request: {session_request.to_json()}")
 
@@ -215,17 +216,22 @@ class AgentClient:
                     f"Unsupported HTTP method {method} in send_request()"
                 )
 
+        response_json = {}
+        # For some successful calls, the response body will be empty
+        # Parsing it results in a ValueError, so we should handle this
+        try:
+            response_json = response.json()
+        except ValueError:
+            pass
+
+        # Handling any HTTPError exceptions.
         try:
             response.raise_for_status()
-            try:
-                # For some successful calls, the response body will be empty
-                # Parsing it results in a ValueError, so we should handle this
-                response_json = response.json()
-            except ValueError:
-                response_json = {}
             return OperationResult(True, response.status_code, "", response_json)
         except HTTPError as http_error:
-            return OperationResult(False, response.status_code, str(http_error), None)
+            return OperationResult(False, response.status_code,
+                                   response_json.get('message', str(http_error)),
+                                   response_json if response_json else None)
 
     def send_action_execution_request(
         self, codeblock_guid: str, body: dict
@@ -375,36 +381,24 @@ class AgentClient:
         Returns:
             AddonExecutionResponse: object containing the result of the action execution
         """
+
+        # Sending proxy request...
         operation_result = self.send_request(
             "POST",
             urljoin(self._remote_address, Endpoint.AddonExecution.value),
             self._create_action_proxy_payload(action),
         )
 
-        if operation_result.status_code == 404:
+        if operation_result.status_code == HTTPStatus.NOT_FOUND:
             logging.error(f'Action [{action.proxydescriptor.classname}] in addon [{action.proxydescriptor.guid}]'
                           f' is not installed in your account.')
             raise AddonNotInstalledException
 
-        response = AddonExecutionResponse()
-        response.executionresulttype = (
-            ExecutionResultType.Passed
-            if operation_result.data["resultType"] == "Passed"
-            else ExecutionResultType.Failed
-        )
-        response.message = operation_result.data["message"]
-        response.fields = []
-
-        fields_in_operation_result = operation_result.data['fields']
-
-        for field in fields_in_operation_result:
-            result_field = ResultField()
-            result_field.name = field['name']
-            result_field.value = field['value']
-            result_field.is_output = field['output']
-            response.fields.append(result_field)
-
-        return response
+        return AddonExecutionResponse(execution_result_type=(ExecutionResultType.Passed
+                                                             if operation_result.data["resultType"] == "Passed"
+                                                             else ExecutionResultType.Failed),
+                                      message=operation_result.data["message"],
+                                      fields=[ResultField(**field) for field in operation_result.data['fields']])
 
     @staticmethod
     def _create_action_proxy_payload(action: ActionProxy) -> dict:
@@ -431,7 +425,7 @@ class AgentClient:
         Args:
             response (OperationResult): response from the Agent
         """
-        if response.status_code == 401:
+        if response.status_code == HTTPStatus.UNAUTHORIZED:
             logging.error(
                 "Failed to initialize a session with the Agent - invalid developer token supplied"
             )
@@ -440,14 +434,10 @@ class AgentClient:
                 " and set it in the TP_DEV_TOKEN environment variable"
             )
             raise InvalidTokenException(response.message)
-        elif response.status_code == 404:
-            try:
-                error_message = f"Requested browser '{self._capabilities['browserName']}' could not be found on your system"
-            except KeyError:
-                error_message = "Requested browser could not be found on your system"
-            logging.error(error_message)
-            raise MissingBrowserException(error_message)
-        elif response.status_code == 406:
+        elif response.status_code == HTTPStatus.NOT_FOUND:
+            error_message = response.message if response.message else "Failed to start a new session!"
+            raise SdkException(error_message)
+        elif response.status_code == HTTPStatus.NOT_ACCEPTABLE:
             logging.error(
                 f"Failed to initialize a session with the Agent - obsolete SDK version {ConfigHelper.get_sdk_version()}"
             )
